oerplib.service.inspect **(New in version 0.8)**
================================================

.. automodule:: oerplib.service.inspect
    :members:

oerplib.service.inspect.Relations
'''''''''''''''''''''''''''''''''

.. autoclass:: oerplib.service.inspect.relations.Relations
    :members:

oerplib.service.inspect.Dependencies
''''''''''''''''''''''''''''''''''''

.. autoclass:: oerplib.service.inspect.dependencies.Dependencies
    :members:
